// Station side of RADIO functions
// Thomas Braunl, UWA 2017
#include <winsock2.h>
#include <ws2tcpip.h>
//#define BYTE char

SOCKET RADIOInit(SOCKET sockfdListening);
int RADIOSend(int id, char* buf, SOCKET sockfdListening);
int RADIOReceive(int id, char *buf);
int RADIOCheck(void);
int RADIORelease(SOCKET sockfdListening);
int RADIOStatus(int IDlist[]);
int FilterActive(int IDlistF[], int IDlistNF[]);
int RADIOGetID(void);
void PingNetwork(void);
